==> hasktags-0.71.2-43-x86_64.pkg.tar.xz: usr/share/haskell/register/hasktags.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hasktags
version: 0.71.2
id: hasktags-0.71.2-7Ylo7AMMa6AAtMWGvo5k4q
key: hasktags-0.71.2-7Ylo7AMMa6AAtMWGvo5k4q
license: BSD-3-Clause
copyright: The University Court of the University of Glasgow
maintainer: Jack Henahan <jhenahan@me.com>,
            Marc Weber <marco-oweber@gmx.de>,
            Marco Túlio Pimenta Gontijo <marcotmarcot@gmail.com>
author: The GHC Team
homepage: http://github.com/MarcWeber/hasktags
synopsis: Produces ctags "tags" and etags "TAGS" files for Haskell programs
description:
    Produces ctags "tags" and etags "TAGS" files for Haskell programs.
category: Development
abi: 3313cf8987fd3db12fec759fa21c02a3
exposed: True
exposed-modules:
    Hasktags
hidden-modules: Tags DebugShow
import-dirs: /usr/lib/ghc-8.6.5/site-local/hasktags-0.71.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/hasktags-0.71.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/hasktags-0.71.2
hs-libraries: HShasktags-0.71.2-7Ylo7AMMa6AAtMWGvo5k4q
depends:
    base-4.12.0.0 bytestring-0.10.8.2 directory-1.3.3.0
    filepath-1.4.2.1 json-0.9.3-KMo6fueTh6fHhtSWtpDb75
    microlens-platform-0.4.0-6tTa415RdxN9EVH3pXTBUh
    utf8-string-1.0.1.1-Geq8jdOv4Q3LkcQoEOWDVv
haddock-interfaces: /usr/share/doc/hasktags/html/hasktags.haddock
haddock-html: /usr/share/doc/hasktags/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> hasktags-0.71.2-45-x86_64.pkg.tar.xz: usr/share/haskell/register/hasktags.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hasktags
version: 0.71.2
id: hasktags-0.71.2-8kGw7FsBIz02MFsJ4yGRKP
key: hasktags-0.71.2-8kGw7FsBIz02MFsJ4yGRKP
license: BSD-3-Clause
copyright: The University Court of the University of Glasgow
maintainer: Jack Henahan <jhenahan@me.com>,
            Marc Weber <marco-oweber@gmx.de>,
            Marco Túlio Pimenta Gontijo <marcotmarcot@gmail.com>
author: The GHC Team
homepage: http://github.com/MarcWeber/hasktags
synopsis: Produces ctags "tags" and etags "TAGS" files for Haskell programs
description:
    Produces ctags "tags" and etags "TAGS" files for Haskell programs.
category: Development
abi: 8c1812ad156f2d69afa2e3423419e42f
exposed: True
exposed-modules:
    Hasktags
hidden-modules: Tags DebugShow
import-dirs: /usr/lib/ghc-8.6.5/site-local/hasktags-0.71.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/hasktags-0.71.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/hasktags-0.71.2
hs-libraries: HShasktags-0.71.2-8kGw7FsBIz02MFsJ4yGRKP
depends:
    base-4.12.0.0 bytestring-0.10.8.2 directory-1.3.3.0
    filepath-1.4.2.1 json-0.9.3-KMo6fueTh6fHhtSWtpDb75
    microlens-platform-0.4.0-37EpiMtV3nA5oty7dCOHgK
    utf8-string-1.0.1.1-Geq8jdOv4Q3LkcQoEOWDVv
haddock-interfaces: /usr/share/doc/hasktags/html/hasktags.haddock
haddock-html: /usr/share/doc/hasktags/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
